==> humhub-1.10.2.tar.gz: humhub-1.10.2/protected/humhub/modules/space/messages/tr/base.php <==
<?php

return [
    '<b>This space is still empty!</b>' => '<b>Bu alan halen boş!</b>',
    '<b>This space is still empty!</b><br>Start by posting something here...' => '<b>Bu mekan hala boş!</b><b>Burada bir şey paylaşarak başla...',
    '<strong>Confirm</strong> image deletion' => 'Resmin silinmesini onayla',
    '<strong>Invite</strong> members' => '<strong>Üye</strong> davet et',
    '<strong>New</strong> member request' => '<strong>Yeni</strong> üye isteği',
    '<strong>New</strong> spaces' => '<strong>Yeni</strong> mekanlar',
    '<strong>Request</strong> space membership' => '<strong>Mekan</strong> üyeliği isteği',
    '<strong>Space</strong> followers' => '<strong>Mekan</strong> takipçileri',
    '<strong>Space</strong> members' => '<strong>Mekan</strong> üyeleri',
    '<strong>Space</strong> menu' => '<strong>Mekan</strong> menüsü',
    'About' => 'Hakkında',
    'Accept' => 'Onayla',
    'Accept Invite' => 'Daveti kabul et',
    'Admin' => 'Yönetici',
    'Administrator:' => 'Yönetici:',
    'Administrators' => 'Yöneticiler',
    'Application message' => 'Uygulama mesajı',
    'Archived' => 'Arşivlenen',
    'As owner you cannot revoke your membership!' => 'Sayfa sahibi olarak siz üyeliğinizi iptal edemezsiniz!',
    'Cancel' => 'İptal',
    'Close' => 'Kapat',
    'Color' => 'Renk',
    'Could not request membership!' => 'Üyelik isteği gerçekleşmedi!',
    'Created At' => 'Oluşturma zamanı',
    'Created By' => 'Oluşturan',
    'Decline' => 'Reddet',
    'Default' => 'Varsayılan',
    'Default content visibility' => 'Varsayılan içerik görünürlüğü',
    'Delete' => 'Sil',
    'Description' => 'Açıklama',
    'Do you really want to delete your profile image?' => 'Profil resmini silmek istiyor musun?',
    'Do you really want to delete your title image?' => 'Kapak resmini silmek istiyor musun?',
    'Done' => 'Tamamla',
    'Email addresses' => 'Email adresleri',
    'Everyone can enter' => 'Herkes girebilir',
    'Follow' => 'Takip et',
    'Followers' => 'Takipçiler',
    'Following' => 'Takip edilenler',
    'Homepage' => 'Anasayfa',
    'Homepage (Guests)' => 'Anasayfa (Misafirler)',
    'Invite' => 'Davet',
    'Invite and request' => 'Davet ve İstek talebi',
    'Invite by email' => 'Email ile davet et',
    'Invites' => 'Davetler',
    'Join Policy' => 'Katılma İlkesi',
    'Last Visit' => 'Son ziyaret',
    'Login' => 'Giriş',
    'Member since' => 'Den beri üye',
    'Members' => 'Üyeler',
    'Moderator:' => 'Moderatör:',
    'Moderators' => 'Moderatörler',
    'My Space List' => 'Mekan listesi',
    'My space summary' => 'Mekan özeti',
    'Name' => 'Ad',
    'New user by e-mail (comma separated)' => 'e-posta adresi ile yeni kullanıcı (virgülle ayılmış)',
    'New user?' => 'Yeni kullanıcı?',
    'No spaces found.' => 'Sayfa bulunamadı.',
    'Only by invite' => 'Sadece davetliler',
    'Originator User ID' => 'Başlatan Kullanıcı ID',
    'Owner' => 'Sahibi',
    'Owner:' => 'Sahip:',
    'Pick users' => 'Kullanıcıları seç',
    'Please shortly introduce yourself, to become a approved member of this workspace.' => 'Bu mekana üye olabilmek için lütfen kısaca kendinizi tanıtın.',
    'Please shortly introduce yourself, to become an approved member of this space.' => 'Lütfen bu mekanın onaylı bir üyesi olmak için kısaca kendinizi tanıtın.',
    'Posts' => 'Mesajlar',
    'Private' => 'Özel',
    'Private (Invisible)' => 'Gizli (Görünmez)',
    'Public' => 'Herkes',
    'Public (Members & Guests)' => 'Genel (Üyeler &amp; Misafirler)',
    'Public (Members only)' => 'Genel (Yalnızca üyeler)',
    'Public (Registered users only)' => 'Genel (Yalnızca kayıtlı kullanıcılar)',
    'Request Message' => 'İstek Mesajı',
    'Request workspace membership' => 'Mekan üyeliği talebi',
    'Role' => 'Rol',
    'See all' => 'Tümünü gör',
    'Send' => 'Gönder',
    'Settings' => 'Ayarlar',
    'Show all' => 'Tümünü göster',
    'Sorry, you are not allowed to leave this space!' => 'Üzgünüz, bu sayfayı terk etmenize izin verilmiyor.',
    'Sorting' => 'Sıralama',
    'Space' => 'Mekan',
    'Space directory' => 'Mekan dizini',
    'Space is invisible!' => 'Sayfa görünmez!',
    'Spaces' => 'Mekanlar',
    'Status' => 'Durum',
    'Stream' => 'Yayın',
    'Tags' => 'Etiketler',
    'There is no pending invite!' => 'Bekleyen davet bulunmuyor!',
    'This action is only available for workspace members!' => 'Bu eylemi yalnızca çalışma alanı üyeleri kullanabilir!',
    'This user is already a member of this space.' => 'Bu kullanıcı zaten bu sayfanın üyesi.',
    'This user is not a member of this space.' => 'Bu kullanıcı bu sayfanın üyesi değil.',
    'To invite users to this space, please type their names below to find and pick them.' => 'Bu mekana kullanıcıları davet etmek, bulmak ve onları almak için aşağıya isimlerini yazınız.',
    'Updated At' => 'Güncelleme zamanı',
    'Updated By' => 'Güncelleyen',
    'Updated by' => 'Güncelleyen',
    'User \'{username}\' is already a member of this space!' => '{username} isimli kullanıcı zaten bu sayfa üyesi!',
    'User invitations have been added to the queue' => 'Kullanıcı davetiyeleri sıraya eklendi',
    'User memberships have been added to the queue' => 'Sıraya kullanıcı üyelikleri eklendi',
    'User not found!' => 'Kullanıcı bulunamadı!',
    'Users' => 'Kullanıcılar',
    'Visibility' => 'Görünüm',
    'Visible for all (members and guests)' => 'Tümü görebilir (Üyeler ve Misafirler)',
    'You are not allowed to join this space!' => 'Bu sayfaya katılmanıza izin verilmiyor!',
    'You can also invite external users, which are not registered now. Just add their e-mail addresses separated by comma.' => 'Dışardan kullanıcı davet edebilirsiniz. Sadece virgülle ayırarak e-posta adreslerini ekleyin.',
    'You cannot create private visible spaces!' => 'Özel görünür sayfalar oluşturamazsınız!',
    'You cannot create public visible spaces!' => 'Genel görünür sayfalar oluşturamazsınız!',
    'You need to login to view contents of this space!' => 'Bu sayfa içeriğini görüntülemek için giriş yapmalısınız!',
    'Your request was successfully submitted to the space administrators.' => 'İsteğiniz başarıyla mekan yöneticilerine gönderildi.',
    'Your request was successfully submitted to the workspace administrators.' => 'İsteğiniz başarılı bir şekilde yöneticilere iletildi.',
    '{count} members' => '{count} üyeler',
    '{email} is not valid!' => '{email} adresi geçersiz!',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '',
    '<strong>About</strong> the Space' => '',
    '<strong>About</strong> your membership' => '',
    '<strong>Space</strong> tags' => '',
    '<strong>Spaces</strong>' => '',
    'Add users without invitation' => '',
    'Any' => '',
    'Blocked users' => '',
    'By Name' => '',
    'Decline Invite' => '',
    'Find Spaces by their description or by their tags' => '',
    'Guests' => '',
    'Hide Members sidebar in the stream page.' => '',
    'Join' => '',
    'Max. 100 characters.' => '',
    'Member' => '',
    'Moderator' => '',
    'Neither..nor' => '',
    'Newest first' => '',
    'No results found!' => '',
    'Oldest first' => '',
    'Pending' => '',
    'Search...' => '',
    'Select all registered users' => '',
    'Settings could not be saved!' => '',
    'Shown on About Page.' => '',
    'Space Visibility' => '',
    'Try other keywords or remove filters.' => '',
    'Users has been invited.' => '',
    'Would you like to end your membership in Space {spaceName}?' => '',
    'Would you like to unfollow Space {spaceName}?' => '',
    'Would you like to unfollow {userName}?' => '',
    'Would you like to withdraw your request to join Space {spaceName}?' => '',
];

==> humhub-1.12.0.tar.gz: humhub-1.12.0/protected/humhub/modules/space/messages/tr/base.php <==
<?php

return [
    '<b>This space is still empty!</b>' => '<b>Bu alan halen boş!</b>',
    '<b>This space is still empty!</b><br>Start by posting something here...' => '<b>Bu mekan hala boş!</b><b>Burada bir şey paylaşarak başla...',
    '<strong>Confirm</strong> image deletion' => 'Resmin silinmesini onayla',
    '<strong>Invite</strong> members' => '<strong>Üye</strong> davet et',
    '<strong>New</strong> member request' => '<strong>Yeni</strong> üye isteği',
    '<strong>New</strong> spaces' => '<strong>Yeni</strong> mekanlar',
    '<strong>Request</strong> Membership' => '<strong>Mekan</strong> üyeliği isteği',
    '<strong>Space</strong> followers' => '<strong>Mekan</strong> takipçileri',
    '<strong>Space</strong> members' => '<strong>Mekan</strong> üyeleri',
    '<strong>Space</strong> menu' => '<strong>Mekan</strong> menüsü',
    'About' => 'Hakkında',
    'Accept' => 'Onayla',
    'Accept Invite' => 'Daveti kabul et',
    'Access to this Space is restricted. Please introduce yourself to become a member.' => 'Lütfen bu mekanın onaylı bir üyesi olmak için kısaca kendinizi tanıtın.',
    'Admin' => 'Yönetici',
    'Administrator:' => 'Yönetici:',
    'Administrators' => 'Yöneticiler',
    'Archived' => 'Arşivlenen',
    'As owner you cannot revoke your membership!' => 'Sayfa sahibi olarak siz üyeliğinizi iptal edemezsiniz!',
    'Cancel' => 'İptal',
    'Close' => 'Kapat',
    'Color' => 'Renk',
    'Could not request membership!' => 'Üyelik isteği gerçekleşmedi!',
    'Created At' => 'Oluşturma zamanı',
    'Created By' => 'Oluşturan',
    'Decline' => 'Reddet',
    'Default' => 'Varsayılan',
    'Default content visibility' => 'Varsayılan içerik görünürlüğü',
    'Delete' => 'Sil',
    'Description' => 'Açıklama',
    'Do you really want to delete your profile image?' => 'Profil resmini silmek istiyor musun?',
    'Do you really want to delete your title image?' => 'Kapak resmini silmek istiyor musun?',
    'Done' => 'Tamamla',
    'Email addresses' => 'Email adresleri',
    'Everyone can enter' => 'Herkes girebilir',
    'Follow' => 'Takip et',
    'Followers' => 'Takipçiler',
    'Following' => 'Takip edilenler',
    'Homepage' => 'Anasayfa',
    'Homepage (Guests)' => 'Anasayfa (Misafirler)',
    'Invite' => 'Davet',
    'Invite and request' => 'Davet ve İstek talebi',
    'Invite by email' => 'Email ile davet et',
    'Invites' => 'Davetler',
    'Join Policy' => 'Katılma İlkesi',
    'Last Visit' => 'Son ziyaret',
    'Login' => 'Giriş',
    'Member since' => 'Den beri üye',
    'Members' => 'Üyeler',
    'Moderator:' => 'Moderatör:',
    'Moderators' => 'Moderatörler',
    'My Space List' => 'Mekan listesi',
    'My space summary' => 'Mekan özeti',
    'Name' => 'Ad',
    'New user by e-mail (comma separated)' => 'e-posta adresi ile yeni kullanıcı (virgülle ayılmış)',
    'New user?' => 'Yeni kullanıcı?',
    'No spaces found.' => 'Sayfa bulunamadı.',
    'Only by invite' => 'Sadece davetliler',
    'Originator User ID' => 'Başlatan Kullanıcı ID',
    'Owner' => 'Sahibi',
    'Owner:' => 'Sahip:',
    'Pick users' => 'Kullanıcıları seç',
    'Posts' => 'Mesajlar',
    'Private' => 'Özel',
    'Private (Invisible)' => 'Gizli (Görünmez)',
    'Public' => 'Herkes',
    'Public (Members & Guests)' => 'Genel (Üyeler &amp; Misafirler)',
    'Public (Members only)' => 'Genel (Yalnızca üyeler)',
    'Public (Registered users only)' => 'Genel (Yalnızca kayıtlı kullanıcılar)',
    'Request Message' => 'İstek Mesajı',
    'Role' => 'Rol',
    'See all' => 'Tümünü gör',
    'Send' => 'Gönder',
    'Settings' => 'Ayarlar',
    'Show all' => 'Tümünü göster',
    'Sorry, you are not allowed to leave this space!' => 'Üzgünüz, bu sayfayı terk etmenize izin verilmiyor.',
    'Sorting' => 'Sıralama',
    'Space' => 'Mekan',
    'Space directory' => 'Mekan dizini',
    'Space is invisible!' => 'Sayfa görünmez!',
    'Spaces' => 'Mekanlar',
    'Status' => 'Durum',
    'Stream' => 'Yayın',
    'Tags' => 'Etiketler',
    'There is no pending invite!' => 'Bekleyen davet bulunmuyor!',
    'This action is only available for workspace members!' => 'Bu eylemi yalnızca çalışma alanı üyeleri kullanabilir!',
    'This user is already a member of this space.' => 'Bu kullanıcı zaten bu sayfanın üyesi.',
    'This user is not a member of this space.' => 'Bu kullanıcı bu sayfanın üyesi değil.',
    'To invite users to this space, please type their names below to find and pick them.' => 'Bu mekana kullanıcıları davet etmek, bulmak ve onları almak için aşağıya isimlerini yazınız.',
    'Updated At' => 'Güncelleme zamanı',
    'Updated By' => 'Güncelleyen',
    'Updated by' => 'Güncelleyen',
    'User \'{username}\' is already a member of this space!' => '{username} isimli kullanıcı zaten bu sayfa üyesi!',
    'User invitations have been added to the queue' => 'Kullanıcı davetiyeleri sıraya eklendi',
    'User memberships have been added to the queue' => 'Sıraya kullanıcı üyelikleri eklendi',
    'User not found!' => 'Kullanıcı bulunamadı!',
    'Users' => 'Kullanıcılar',
    'Visibility' => 'Görünüm',
    'Visible for all (members and guests)' => 'Tümü görebilir (Üyeler ve Misafirler)',
    'You are not allowed to join this space!' => 'Bu sayfaya katılmanıza izin verilmiyor!',
    'You can also invite external users, which are not registered now. Just add their e-mail addresses separated by comma.' => 'Dışardan kullanıcı davet edebilirsiniz. Sadece virgülle ayırarak e-posta adreslerini ekleyin.',
    'You cannot create private visible spaces!' => 'Özel görünür sayfalar oluşturamazsınız!',
    'You cannot create public visible spaces!' => 'Genel görünür sayfalar oluşturamazsınız!',
    'You need to login to view contents of this space!' => 'Bu sayfa içeriğini görüntülemek için giriş yapmalısınız!',
    'Your Message' => 'Uygulama mesajı',
    'Your request was successfully submitted to the space administrators.' => 'İsteğiniz başarıyla mekan yöneticilerine gönderildi.',
    '{count} members' => '{count} üyeler',
    '{email} is not valid!' => '{email} adresi geçersiz!',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '',
    '<strong>About</strong> the Space' => '',
    '<strong>About</strong> your membership' => '',
    '<strong>Space</strong> tags' => '',
    '<strong>Spaces</strong>' => '',
    'Add users without invitation' => '',
    'Any' => '',
    'Blocked users' => '',
    'By Name' => '',
    'Decline Invite' => '',
    'Find Spaces by their description or by their tags' => '',
    'Guests' => '',
    'Hide Members sidebar in the stream page.' => '',
    'I want to become a member because...' => '',
    'Join' => '',
    'Max. 100 characters.' => '',
    'Member' => '',
    'Moderator' => '',
    'Neither..nor' => '',
    'Newest first' => '',
    'No results found!' => '',
    'Oldest first' => '',
    'Pending' => '',
    'Search...' => '',
    'Select all registered users' => '',
    'Settings could not be saved!' => '',
    'Shown on About Page.' => '',
    'Space Visibility' => '',
    'Try other keywords or remove filters.' => '',
    'Users has been invited.' => '',
    'Would you like to end your membership in Space {spaceName}?' => '',
    'Would you like to unfollow Space {spaceName}?' => '',
    'Would you like to unfollow {userName}?' => '',
    'Would you like to withdraw your request to join Space {spaceName}?' => '',
];
